#
# Configuration file for using the XML library in GNOME applications
#
XMLSEC_LIBDIR="-L${libdir}"
XMLSEC_LIBS="-lxmlsec -L/usr/lib -lxml2 -lz -lm"
XMLSEC_INCLUDEDIR="-I${prefix}/include  -I/usr/include/libxml2"
MODULE_VERSION="xmlsec-0.0.9"

